==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/bn.php <==
<?php

return [
    'Names' => [
        'Arab' => 'আরবি',
        'Armi' => 'আরমি',
        'Armn' => 'আর্মেনীয়',
        'Avst' => 'আভেসতান',
        'Bali' => 'বালীয়',
        'Batk' => 'বাটাক',
        'Beng' => 'বাংলা',
        'Blis' => 'ব্লিসপ্রতীক',
        'Bopo' => 'বোপোমোফো',
        'Brah' => 'ব্রাহ্মী',
        'Brai' => 'ব্রেইল',
        'Bugi' => 'বুগি',
        'Buhd' => 'বুহিড',
        'Cakm' => 'চাকমা',
        'Cans' => 'সংযুক্ত কানাডিয়ান অ্যাব্রোজিনিয়ান সিলেবিক্স',
        'Cari' => 'ক্যারিয়ান',
        'Cham' => 'চ্যাম',
        'Cher' => 'চেরোকি',
        'Cirt' => 'কির্ট',
        'Copt' => 'কোপ্টিক',
        'Cprt' => 'সাইপ্রোয়েট',
        'Cyrl' => 'সিরিলিক',
        'Cyrs' => 'প্রাচীন চার্চ স্লাভোনিক সিরিলিক',
        'Deva' => 'দেবনাগরি',
        'Dsrt' => 'দেসেরাত',
        'Egyd' => 'মিশরীয় ডেমোটিক',
        'Egyh' => 'মিশরীয় হায়রেটিক',
        'Egyp' => 'মিশরীয় হায়ারোগ্লিপ',
        'Ethi' => 'ইথিওপিয়',
        'Geok' => 'জর্জিয় খুৎসুরি',
        'Geor' => 'জর্জিয়ান',
        'Glag' => 'গ্লাগোলিটিক',
        'Goth' => 'গোথিক',
        'Grek' => 'গ্রিক',
        'Gujr' => 'গুজরাটি',
        'Guru' => 'গুরুমুখি',
        'Hanb' => 'হ্যানবি',
        'Hang' => 'হাঙ্গুল',
        'Hani' => 'হ্যান',
        'Hano' => 'হ্যানুনু',
        'Hans' => 'সরলীকৃত',
        'Hant' => 'ঐতিহ্যবাহী',
        'Hebr' => 'হিব্রু',
        'Hira' => 'হিরাগানা',
        'Hmng' => 'ফাহাও মঙ',
        'Hrkt' => 'জাপানি অক্ষরমালা',
        'Hung' => 'পুরোনো হাঙ্গেরীয়',
        'Inds' => 'সিন্ধু',
        'Ital' => 'প্রাচীন ইতালি',
        'Jamo' => 'জ্যামো',
        'Java' => 'জাভানিজ',
        'Jpan' => 'জাপানী',
        'Kali' => 'কায়াহ লি',
        'Kana' => 'কাটাকানা',
        'Khar' => 'খরোষ্ঠী',
        'Khmr' => 'খেমের',
        'Knda' => 'কানাড়া',
        'Kore' => 'কোরিয়ান',
        'Kthi' => 'কাইথি',
        'Lana' => 'লান্না',
        'Laoo' => 'লাও',
        'Latf' => 'ফ্রাক্টুর ল্যাটিন',
        'Latg' => 'গ্যালিক ল্যাটিন',
        'Latn' => 'ল্যাটিন',
        'Lepc' => 'লেপ্চা',
        'Limb' => 'লিম্বু',
        'Lina' => 'লিনিয়ার এ',
        'Linb' => 'লিনিয়ার বি',
        'Lyci' => 'লাইসিয়ান',
        'Lydi' => 'লাইডিয়ান',
        'Mand' => 'ম্যান্ডায়ীন',
        'Mani' => 'ম্যানিচাইন',
        'Maya' => 'মায়ান হায়ারোগ্লিপ',
        'Mero' => 'মেরোইটিক',
        'Mlym' => 'মালায়ালাম',
        'Mong' => 'মোঙ্গোলীয়',
        'Moon' => 'মুন',
        'Mtei' => 'মেইটেই মায়েক',
        'Mymr' => 'মায়ানমার',
        'Nkoo' => 'এনকো',
        'Ogam' => 'ওঘাম',
        'Olck' => 'ওল চিকি',
        'Orkh' => 'অর্খোন',
        'Orya' => 'ওড়িয়া',
        'Osma' => 'ওসমানিয়',
        'Perm' => 'প্রাচীন পার্মিক',
        'Phag' => 'ফাগ্স-পা',
        'Phli' => 'খদিত পাহলভি',
        'Phlp' => 'সল্টার পাহলভি',
        'Phlv' => 'পুস্তক পাহলভি',
        'Phnx' => 'ফিনিশিয়',
        'Plrd' => 'পোলার্ড ধ্বনিক',
        'Prti' => 'পার্থিয়ন',
        'Rjng' => 'রেজ্যাঙ্গ',
        'Roro' => 'রোঙ্গোরোঙ্গো',
        'Runr' => 'রুনিক',
        'Samr' => 'সমেরিটন',
        'Sara' => 'সারাতি',
        'Saur' => 'সৌরাষ্ট্র',
        'Sgnw' => 'চিহ্ন লিখন',
        'Shaw' => 'সাভিয়ান',
        'Sinh' => 'সিংহলি',
        'Sund' => 'সান্দানিজ',
        'Sylo' => 'সিলেটি নাগরি',
        'Syrc' => 'সিরিয়াক',
        'Syre' => 'এস্ট্রেঙ্গেলো সিরিয়াক',
        'Syrj' => 'পশ্চিমাঞ্চলীয় সিরিয়াক',
        'Syrn' => 'পূর্বাঞ্চলীয় সিরিয়াক',
        'Tagb' => 'টাগোওয়ানা',
        'Tale' => 'তাইলে',
        'Talu' => 'নতুন তাই লু',
        'Taml' => 'তামিল',
        'Tavt' => 'তাই ভিয়েৎ',
        'Telu' => 'তেলেগু',
        'Teng' => 'তেঙ্গোয়ার',
        'Tfng' => 'তিফিনাগ',
        'Tglg' => 'টাগালগ',
        'Thaa' => 'থানা',
        'Thai' => 'থাই',
        'Tibt' => 'তিব্বতি',
        'Ugar' => 'উগারিটিক',
        'Vaii' => 'ভাই',
        'Visp' => 'দৃশ্যমান ভাষা',
        'Xpeo' => 'প্রাচীন ফার্সি',
        'Xsux' => 'সুমের-আক্কাদীয় কীলকরূপ',
        'Yiii' => 'উই',
        'Zinh' => 'কাই',
        'Zmth' => 'গাণিতিক চিহ্ন',
        'Zsye' => 'ইমোজি',
        'Zsym' => 'প্রতীকগুলি',
        'Zxxx' => 'অলিখিত',
        'Zyyy' => 'সাধারন',
    ],
];

==> symfony_7.4.0+dfsg.orig.tar.xz: symfony-7.4.0/src/Symfony/Component/Intl/Resources/data/scripts/bn.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'আদলাম',
        'Arab' => 'আরবি',
        'Aran' => 'নাস্তালিক',
        'Armi' => 'আরমি',
        'Armn' => 'আর্মেনীয়',
        'Avst' => 'আভেসতান',
        'Bali' => 'বালীয়',
        'Batk' => 'বাটাক',
        'Beng' => 'বাংলা',
        'Blis' => 'ব্লিসপ্রতীক',
        'Bopo' => 'বোপোমোফো',
        'Brah' => 'ব্রাহ্মী',
        'Brai' => 'ব্রেইল',
        'Bugi' => 'বুগি',
        'Buhd' => 'বুহিড',
        'Cakm' => 'চাকমা',
        'Cans' => 'সংযুক্ত কানাডিয়ান অ্যাবোরিজিনাল সিলেবিক্স',
        'Cari' => 'ক্যারিয়ান',
        'Cham' => 'চ্যাম',
        'Cher' => 'চেরোকি',
        'Cirt' => 'কির্ট',
        'Copt' => 'কোপ্টিক',
        'Cprt' => 'সাইপ্রোয়েট',
        'Cyrl' => 'সিরিলিক',
        'Cyrs' => 'প্রাচীন চার্চ স্লাভোনিক সিরিলিক',
        'Deva' => 'দেবনাগরী',
        'Dsrt' => 'দেসেরাত',
        'Egyd' => 'মিশরীয় ডেমোটিক',
        'Egyh' => 'মিশরীয় হায়রেটিক',
        'Egyp' => 'মিশরীয় হায়ারোগ্লিপ',
        'Ethi' => 'ইথিওপিয়',
        'Geok' => 'জর্জিয় খুৎসুরি',
        'Geor' => 'জর্জীয়',
        'Glag' => 'গ্লাগোলিটিক',
        'Goth' => 'গোথিক',
        'Grek' => 'গ্রিক',
        'Gujr' => 'গুজরাটি',
        'Guru' => 'গুরুমুখি',
        'Hanb' => 'হ্যান-বোপোমোফো',
        'Hang' => 'হাঙ্গুল',
        'Hani' => 'হ্যান',
        'Hano' => 'হ্যানুনু',
        'Hans' => 'সরলীকৃত',
        'Hant' => 'ঐতিহ্যবাহী',
        'Hebr' => 'হিব্রু',
        'Hira' => 'হিরাগানা',
        'Hmng' => 'ফাহাও মঙ',
        'Hrkt' => 'জাপানি অক্ষরমালা',
        'Hung' => 'পুরোনো হাঙ্গেরীয়',
        'Inds' => 'সিন্ধু',
        'Ital' => 'প্রাচীন ইতালি',
        'Jamo' => 'জ্যামো',
        'Java' => 'জাভানিজ',
        'Jpan' => 'জাপানী',
        'Kali' => 'কায়াহ লি',
        'Kana' => 'কাটাকানা',
        'Khar' => 'খরোষ্ঠী',
        'Khmr' => 'খমের',
        'Knda' => 'কানাড়া',
        'Kore' => 'কোরিয়ান',
        'Kthi' => 'কাইথি',
        'Lana' => 'লান্না',
        'Laoo' => 'লাও',
        'Latf' => 'ফ্রাক্টুর ল্যাটিন',
        'Latg' => 'গ্যালিক ল্যাটিন',
        'Latn' => 'ল্যাটিন',
        'Lepc' => 'লেপ্চা',
        'Limb' => 'লিম্বু',
        'Lina' => 'লিনিয়ার এ',
        'Linb' => 'লিনিয়ার বি',
        'Lyci' => 'লাইসিয়ান',
        'Lydi' => 'লাইডিয়ান',
        'Mand' => 'ম্যান্ডায়ীন',
        'Mani' => 'ম্যানিচাইন',
        'Maya' => 'মায়ান হায়ারোগ্লিপ',
        'Mero' => 'মেরোইটিক',
        'Mlym' => 'মালায়ালাম',
        'Mong' => 'মোঙ্গোলীয়',
        'Moon' => 'মুন',
        'Mtei' => 'মেইতেই মায়েক',
        'Mymr' => 'মায়ানমার',
        'Nkoo' => 'এন’কো',
        'Ogam' => 'ওঘাম',
        'Olck' => 'অলচিকি',
        'Orkh' => 'অর্খোন',
        'Orya' => 'ওড়িয়া',
        'Osma' => 'ওসমানিয়',
        'Perm' => 'প্রাচীন পার্মিক',
        'Phag' => 'ফাগ্স-পা',
        'Phli' => 'খদিত পাহলভি',
        'Phlp' => 'সল্টার পাহলভি',
        'Phlv' => 'পুস্তক পাহলভি',
        'Phnx' => 'ফিনিশিয়',
        'Plrd' => 'পোলার্ড ধ্বনিক',
        'Prti' => 'পার্থিয়ন',
        'Rjng' => 'রেজ্যাঙ্গ',
        'Rohg' => 'হানিফি',
        'Roro' => 'রোঙ্গোরোঙ্গো',
        'Runr' => 'রুনিক',
        'Samr' => 'সমেরিটন',
        'Sara' => 'সারাতি',
        'Saur' => 'সৌরাষ্ট্র',
        'Sgnw' => 'চিহ্ন লিখন',
        'Shaw' => 'সাভিয়ান',
        'Sinh' => 'সিংহলি',
        'Sund' => 'সুন্দানিজ',
        'Sylo' => 'সিলেটি নাগরি',
        'Syrc' => 'সিরীয়',
        'Syre' => 'এস্ট্রেঙ্গেলো সিরিয়াক',
        'Syrj' => 'পশ্চিমাঞ্চলীয় সিরিয়াক',
        'Syrn' => 'পূর্বাঞ্চলীয় সিরিয়াক',
        'Tagb' => 'টাগোওয়ানা',
        'Tale' => 'তাইলে',
        'Talu' => 'নতুন তাই লু',
        'Taml' => 'তামিল',
        'Tavt' => 'তাই ভিয়েৎ',
        'Telu' => 'তেলেগু',
        'Teng' => 'তেঙ্গোয়ার',
        'Tfng' => 'তিফিনাগ',
        'Tglg' => 'টাগালগ',
        'Thaa' => 'থানা',
        'Thai' => 'থাই',
        'Tibt' => 'তিব্বতি',
        'Ugar' => 'উগারিটিক',
        'Vaii' => 'ভাই',
        'Visp' => 'দৃশ্যমান ভাষা',
        'Xpeo' => 'প্রাচীন ফার্সি',
        'Xsux' => 'সুমের-আক্কাদীয় কীলকরূপ',
        'Yiii' => 'ই',
        'Zinh' => 'কাই',
        'Zmth' => 'গাণিতিক চিহ্ন',
        'Zsye' => 'ইমোজি',
        'Zsym' => 'প্রতীক',
        'Zxxx' => 'অলিখিত',
        'Zyyy' => 'সাধারন',
    ],
];
